@@ -78,7 +78,7 @@ def _is_dataclass_repr(obj: object) -> bool:
     # Catching all exceptions in case something is missing on a non CPython implementation
     try:
         return obj.__repr__.__code__.co_filename == dataclasses.__file__
-    except Exception:
+    except Exception:  # pragma: no coverage
         return False
 
 
@@ -654,12 +654,11 @@ def traverse(
             )
 
             for last, field in loop_last(field for field in fields(obj) if field.repr):
-                if field.repr:
-                    child_node = _traverse(getattr(obj, field.name))
-                    child_node.key_repr = field.name
-                    child_node.last = last
-                    child_node.key_separator = "="
-                    append(child_node)
+                child_node = _traverse(getattr(obj, field.name))
+                child_node.key_repr = field.name
+                child_node.last = last
+                child_node.key_separator = "="
+                append(child_node)
 
             pop_visited(obj_id)
 
